<?php
namespace csplite;

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (!class_exists('WdmUserSpecificPricing')) {

    class WdmUserSpecificPricing
    {
        private $has_csp = false;
        public function __construct()
        {
            add_action('woocommerce_product_write_panel_tabs', array(
                $this, 'userSpecificPricingTab'));
                // Removed as the woocommerce_product_write_panels is deprecated instead used woocommerce_product_data_panels
            // add_action('woocommerce_product_write_panels', array(
            // $this, 'userSpecificPricingTabOptions', ));

            if (defined('WC_VERSION')) {
                $this->hookWcGetPriceFilter();
            } else {
                add_action('woocommerce_loaded', array($this, 'hookWcGetPriceFilter'));
            }

            add_action('woocommerce_product_data_panels', array(
                $this, 'userSpecificPricingTabOptions', ));

            add_action('woocommerce_process_product_meta_simple', array(
                $this, 'processUserPricingPairs'));
            add_filter('woocommerce_product_is_on_sale', array($this, 'showCSPAsSalePrice', ), 1, 2);
            // add_filter('woocommerce_get_price', array($this, 'applyCustomPrice', ), 99, 2);
        }

        public function hookWcGetPriceFilter()
        {
            if (version_compare(WC_VERSION, '3.0', '<')) {
                add_filter('woocommerce_get_price', array($this, 'applyCustomPrice', ), 99, 2);
            } else {
                 add_filter('woocommerce_product_get_price', array($this, 'applyCustomPrice', ), 99, 2);
            }
        }

        public function showCSPAsSalePrice($onSale, $product)
        {
            if (!$this->has_csp) {
                return $onSale;
            }

            return $product->get_price() >= floatval(get_post_meta($product->get_id(), '_regular_price', true)) ? false : true;
        }

        /**
         * Shows User Specific Pricing tab on Product create/edit page
         *
         * This tab shows options to add price for specific users
         * while creating a product or editing the product.
         */
        public function userSpecificPricingTab()
        {
            ?>
            <li class="user_specific_pricing_tab show_if_simple">
                <a href="#user_specific_pricing_tab_data"><?php _e('Customer Specific Pricing', 'customer-specific-pricing-lite'); ?></a>
            </li>
            <?php
        }

        /**
         * User Specific Tab Content
         * Shows the tab content i.e. allows admin to add pair and
         * remove user-price pair
         */
        public function userSpecificPricingTabOptions()
        {
            include(
                trailingslashit(
                    dirname(
                        dirname(__FILE__)
                    )
                ) . 'templates/print_user_specific_pricing_tab_content.php'
            );
        }

    /**
     * Process meta
     *
     * Processes the custom tab options when a post is saved
     */
        public function processUserPricingPairs($product_id)
        {

            $username_array  = (isset($_POST['wdm_woo_username']) ? $_POST['wdm_woo_username'] : array());
            $price_array     = (isset($_POST['wdm_woo_price']) ? $_POST['wdm_woo_price'] : array());
            $price_type      = self::getPriceTypeArray();

            $result = self::updatePairs($product_id, $username_array, $price_array, $price_type);

            $username_array  = array_values($username_array);
            $price_array     = array_values($price_array);
            $price_type = array_values($price_type);

            $_POST['wdm_woo_username'] = $result['wdm_username'];
            $_POST['wdm_woo_price'] = $result['wdm_prices'];
            $_POST['wdm_price_type'] = $result['wdm_price_type'];
            if (array_key_exists('wdm_woo_username', $_POST) && count($_POST['wdm_woo_username']) > 0) {
                self::savePricing($_POST['wdm_woo_username'], $price_array, $product_id, $price_type);
            }//if ends -- array key exist & array wdm_woo_username > 0



            // $username_array  = (isset($_POST['wdm_woo_username']) ? $_POST['wdm_woo_username'] : array());
            // $price_array     = (isset($_POST['wdm_woo_price']) ? $_POST['wdm_woo_price'] : array());

            // $result = self::updatePairs($product_id, $username_array, $price_array);

            // $username_array  = array_values($username_array);
            // $price_array     = array_values($price_array);

            // $_POST['wdm_woo_username'] = $result['wdm_username'];
            // $_POST['wdm_woo_price'] = $result['wdm_prices'];

            // if (array_key_exists('wdm_woo_username', $_POST) && count($_POST['wdm_woo_username']) > 0) {

            //     self::savePricing($_POST['wdm_woo_username'], $price_array, $product_id);

            // }//if ends -- array key exist & array wdm_woo_username > 0
        }//function ends


        private function savePricing($username_array, $price_array, $product_id, $price_type)
        {
            if (count($username_array) > 0) {
                foreach ($username_array as $username) {
                    $find_out_user_key = self::searchAllOccurrences($username_array, $username);
                    if (isset($price_array[$find_out_user_key[0]]) && ! empty($price_array[$find_out_user_key[0]])) {
                        \csplite\WdmWuspAddDataInDB::insertPricingInDb($username_array[$find_out_user_key[0]], $product_id, isset($price_array[$find_out_user_key[0]]) ? $price_array[$find_out_user_key[0]] : '', isset($price_type) ? $price_type[$find_out_user_key[0]] : '');
                    }

                    //Unset other values for same user
                    foreach ($find_out_user_key as $value) {
                        unset($username_array[$value]);
                        unset($price_type[$value]);
                        unset($price_array[$value]);
                    }
                }//foreach ends
            }//if ends
        }

        public function getPriceTypeArray()
        {
            if (isset($_POST['wdm_price_type'])) {
                return $_POST['wdm_price_type'];
            } else {
                return array();
            }
        }

        public function searchAllOccurrences($arr, $needle)
        {
            $array_keys = array();
            foreach ($arr as $key => $value) {
                if ($value == $needle) {
                    array_push($array_keys, $key);
                }
            }
            return $array_keys;
        }

        // private function savePricing($username_array, $price_array, $product_id)
        // {
        //     if (count($username_array) > 0) {
        //         foreach ($username_array as $username) {
        //             $i = array_search($username, $username_array);
        //             if (isset($price_array[$i]) && ! empty($price_array[$i])) {
        //                 \csplite\WdmWuspAddDataInDB::insertPricingInDb($username_array[$i], $product_id, isset($price_array[$i]) ? $price_array[$i] : '', 1);
        //             }
        //         }//foreach ends
        //     }//if ends
        // }


        private function updatePairs($product_id, $wdm_woo_username, $wdm_woo_price, $price_type)
        {
            //Delete unwanted combinations
            global $wpdb;
            
            $wusp_pricing_table  = $wpdb->prefix . 'wusp_user_pricing_mapping';
            $user_product_mapping   = $wpdb->get_results($wpdb->prepare("SELECT id, user_id, price, flat_or_discount_price FROM {$wusp_pricing_table} WHERE product_id=%d", $product_id));

            //retrieve all subrules before processing
            $result = array();
            
            if ($user_product_mapping) {
                foreach ($user_product_mapping as $single_mapping) {
                    //Pairs which are in db but not in form submisisons need to be deleted
                    if (! in_array($single_mapping->user_id, $wdm_woo_username)) {
                        $wpdb->delete($wusp_pricing_table, array( 'id' => $single_mapping->id ), array(
                        '%d',
                        ));
                    } else {
                        //Pairs which are in db and also there in new form submissions need to be updated
                        $find_out_user_key = self::searchAllOccurrences($wdm_woo_username, $single_mapping->user_id);

                        if (empty($wdm_woo_price[$find_out_user_key[0]]) || ! isset($wdm_woo_price[$find_out_user_key[0]])) {
                            //remove pair if price is empty
                            $wusp_pricing_table  = $wpdb->prefix . 'wusp_user_pricing_mapping';
                            $wpdb->delete($wusp_pricing_table, array(
                                'id' => $single_mapping->id, ), array(
                                '%d',
                                ));
                        } else {
                            $wpdb->update(
                                $wusp_pricing_table,
                                array(
                                'price' => $wdm_woo_price[$find_out_user_key[0]],
                                'flat_or_discount_price' => $price_type[$find_out_user_key[0]]
                                ),
                                array(
                                'id' => $single_mapping->id,
                                )
                            );
                        }

                        //Unset other values for same user
                        foreach ($find_out_user_key as $val) {
                            unset($wdm_woo_username[$val]);
                            unset($wdm_woo_price[$val]);
                            unset($price_type[$val]);
                        }
                    }
                }
            }//if ends -- User - product mapping exists
            
            $result['wdm_username'] = $wdm_woo_username;
            $result['wdm_prices'] = $wdm_woo_price;
            $result['wdm_price_type'] = $price_type;
            //exit;
            return $result;
        }


        // private function updatePairs($product_id, $wdm_woo_username, $wdm_woo_price)
        // {
        //     //Delete unwanted combinations
        //     global $wpdb;

        //     $wusp_pricing_table  = $wpdb->prefix . 'wusp_user_pricing_mapping';
        //     $user_product_mapping   = $wpdb->get_results($wpdb->prepare("SELECT id, user_id, price FROM {$wusp_pricing_table} WHERE product_id=%d", $product_id));

        //     $result = array();

        //     if ($user_product_mapping) {
        //         foreach ($user_product_mapping as $single_mapping) {
        //             //Pairs which are in db but not in form submisisons need to be deleted
        //             if (! in_array($single_mapping->user_id, $wdm_woo_username)) {
        //                 $wpdb->delete($wusp_pricing_table, array( 'id' => $single_mapping->id ), array(
        //                 '%d',
        //                 ));
        //             } else {
        //                 //Pairs which are in db and also there in new form submissions need to be updated
        //                 $find_out_user_key = array_search($single_mapping->user_id, $wdm_woo_username);

        //                 $wpdb->update($wusp_pricing_table, array(
        //                 'price' => $wdm_woo_price[$find_out_user_key] ), array(
        //                 'id' => $single_mapping->id, ));

        //                 unset($wdm_woo_username[$find_out_user_key]);
        //                 unset($wdm_woo_price[$find_out_user_key]);
        //             }
        //         }
        //     } //if ends -- User - product mapping exists

        //     $result['wdm_username'] = $wdm_woo_username;
        //     $result['wdm_prices'] = $wdm_woo_price;
        //     //exit;
        //     return $result;
        // }

    /**
     * Apply Custom Price when user adds the product in the cart.
     */
        public function applyCustomPrice($price, $product)
        {
            //If user is not logged in, Original Price should be returned
            if (! is_user_logged_in()) {
                return $price;
            }
            $user_id     = get_current_user_id();
            $product_id  = $product->get_id();
            if (isset($product->variation_id)) {
                $product_id = $product->variation_id;
            }

            if (is_callable(array($product, 'get_type'))) {
                $product_type = $product->get_type();
            } else {
                $product_type = $product->product_type;
            }

            if ('simple' == $product_type) {
                $product_id = $product->get_id();
            }

            $db_price = self::getDBPrice($user_id, $product_id, $price);

            if (isset($db_price) && $db_price) {
                return $db_price;
            } else {
                return $price; //return defalult set price
            }
        }

    /**
     * Apply Custom Price when user adds the product in the cart.
     */
        // public function applyCustomPrice($price, $product)
        // {
        //     //If user is not logged in, Original Price should be returned
        //     if (! is_user_logged_in()) {
        //         return $price;
        //     // Client's Requirement
        //     //     remove_action('woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10);
        //     //     remove_action('woocommerce_single_product_summary', 'woocommerce_template_single_price', 10);
        //     }
        //     $user_id     = get_current_user_id();
        //     $product_id  = $product->id;
        //     if (isset($product->variation_id)) {
        //         $product_id = $product->variation_id;
        //     }

        //     if ('simple' == $product->product_type) {
        //         $product_id = $product->id;
        //     }

        //     $db_price = self::getDBPrice($user_id, $product_id, $price);

        //     if (isset($db_price) && $db_price) {
        //         return $db_price;
        //     } else {
        //         return $price; //return defalult set price
        //     }
        // }

        private function getDBPrice($user_id, $product_id, $price)
        {
            $db_price = $price;

            $csp_price           = \csplite\WdmWuspGetData::getPriceOfProductForUser($user_id, $product_id);

            if (isset($csp_price)&& !empty($csp_price)) {
                $this->has_csp = true;
                $db_price = $csp_price;
            }
            return $db_price;
        }
    }

}

